@@ -14,12 +14,8 @@ def print_traceback(caption="Error", message=""):
         message (str, optional): Heading of detailed traceback. Defaults to "Error".
     """
     mylogging.traceback(
-        f"Catched error - server still running.\n\n{message}",
-        caption,
+        f"Catched error - server still running.\n\n{message}", caption,
     )
     pyvueeel.eel.create_alert(
-        caption,
-        message,
-        traceback.format_exc(),
-        "error",
+        caption, message, traceback.format_exc(), "error",
     )
