@@ -125,7 +125,8 @@ class MyPropertyClass(Generic[T]):
         else:
             result = content
 
-        check_type(expected_type=self.allowed_types, value=result, argname=self.public_name)
+        if self.allowed_types:
+            check_type(expected_type=self.allowed_types, value=result, argname=self.public_name)
 
         self.default_fset(object, result)
 
@@ -138,9 +139,7 @@ def init_my_properties(self):
         if type(j) is MyPropertyClass:
             self.myproperties_list.append(j.public_name)
             setattr(
-                self,
-                j.private_name,
-                j.init_function,
+                self, j.private_name, j.init_function,
             )
 
 
